Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5491)

Unified Diff: chrome/browser/ui/views/toolbar_view.h

Issue 10453101: Convert most of the rest of chrome to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/theme_background.cc ('k') | chrome/browser/ui/views/toolbar_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/toolbar_view.h
diff --git a/chrome/browser/ui/views/toolbar_view.h b/chrome/browser/ui/views/toolbar_view.h
index d77f4e1f5ccdb8556f1c89eaa6ea47e172e2f49a..d3e67bcb25b3f9c5d671dd216e4664b380c2e627 100644
--- a/chrome/browser/ui/views/toolbar_view.h
+++ b/chrome/browser/ui/views/toolbar_view.h
@@ -69,9 +69,9 @@ class ToolbarView : public views::AccessiblePaneView,
// Remove a menu listener.
void RemoveMenuListener(views::MenuListener* listener);
// Gets a bitmap with the icon for the app menu and any overlaid notification
// badge.
- SkBitmap GetAppMenuIcon(views::CustomButton::ButtonState state);
+ gfx::ImageSkia GetAppMenuIcon(views::CustomButton::ButtonState state);
virtual bool GetAcceleratorInfo(int id, ui::Accelerator* accel);
@@ -182,7 +182,7 @@ class ToolbarView : public views::AccessiblePaneView,
// Gets a badge for the wrench icon corresponding to the number of
// unacknowledged background pages in the system.
- SkBitmap GetBackgroundPageBadge();
+ gfx::ImageSkia GetBackgroundPageBadge();
scoped_ptr<BackForwardMenuModel> back_menu_model_;
scoped_ptr<BackForwardMenuModel> forward_menu_model_;
« no previous file with comments | « chrome/browser/ui/views/theme_background.cc ('k') | chrome/browser/ui/views/toolbar_view.cc » ('j') | no next file with comments »
@@ -69,9 +69,9 @@ class ToolbarView : public views::AccessiblePaneView,
// Remove a menu listener.
void RemoveMenuListener(views::MenuListener* listener);
- // Gets a bitmap with the icon for the app menu and any overlaid notification
+ // Gets an image with the icon for the app menu and any overlaid notification
// badge.

Powered by Google App Engine
This is Rietveld 408576698